@@ -1,7 +1,7 @@
 # Programmer friendly subprocess wrapper.
 #
 # Author: Peter Odding <peter@peterodding.com>
-# Last Change: May 25, 2015
+# Last Change: May 26, 2015
 # URL: https://executor.readthedocs.org
 
 """
@@ -91,7 +91,7 @@ def foreach(hosts, *command, **options):
     options.setdefault('capture', True)
     # Create a command pool.
     timer = Timer()
-    pool = CommandPool(concurrency)
+    pool = RemoteCommandPool(concurrency)
     hosts_pluralized = pluralize(len(hosts), "host")
     logger.debug("Preparing to run remote command on %s (%s) with a concurrency of %i: %s",
                  hosts_pluralized, concatenate(hosts), concurrency, quote(command))
@@ -349,12 +349,13 @@ class RemoteCommand(ExternalCommand):
           automatically in all cases. The argument must be "yes", "no", or
           "ask". The default is "ask".
 
-        This property defaults to ``'no'`` so that when you connect to a remote
-        system over SSH for the first time the host key is automatically added
-        to the user known hosts file. As mentioned in the quote above the host
-        keys of known hosts are always verified. Python values are mapped to
-        SSH client option values as follows:
+        This property defaults to :data:`False` so that when you connect to a
+        remote system over SSH for the first time the host key is automatically
+        added to the user known hosts file (instead of requiring interaction).
+        As mentioned in the quote above the host keys of known hosts are always
+        verified (but see :attr:`ignore_known_hosts`).
         """
+        return False
 
     @mutable_property
     def known_hosts_file(self, value=None):
@@ -374,6 +375,31 @@ class RemoteCommand(ExternalCommand):
         return value
 
 
+class RemoteCommandPool(CommandPool):
+
+    """
+    Execute multiple remote commands concurrently.
+
+    After constructing a :class:`RemoteCommandPool` instance you add commands
+    to it using :func:`add()` and when you're ready to run the commands you
+    call :func:`run()`.
+
+    .. note:: The only difference between :class:`.CommandPool` and
+              :class:`RemoteCommandPool` is the default concurrency. This may
+              of course change in the future.
+    """
+
+    def __init__(self, concurrency=DEFAULT_CONCURRENCY):
+        """
+        Construct a :class:`RemoteCommandPool` object.
+
+        :param concurrency: Override the value of :attr:`concurrency` (an
+                            integer, defaults to :data:`DEFAULT_CONCURRENCY`
+                            for remote command pools).
+        """
+        super(RemoteCommandPool, self).__init__(concurrency)
+
+
 class RemoteCommandFailed(ExternalCommandFailed):
     """Raised by :func:`foreach()` when a remote command executed over SSH fails."""
 
